@@ -1,6 +1,6 @@
 /* imvirt / Generic detection code
  *
- * $Id: detect.h 490 2010-03-03 12:46:36Z liske $
+ * $Id: detect.h 592 2012-05-14 17:43:04Z liske $
  *
  * Authors:
  *   Thomas Liske <liske@ibh.de>
@@ -30,6 +30,20 @@ extern int debug_cpuid;
 
 void helper_main(int, char **);
 
-#define CPUID(idx,a,b,c,d)\
-  asm volatile("cpuid": "=a" (a), "=b" (b), "=c" (c), "=d" (d) : "0" (idx)); \
-  if(debug_cpuid) fprintf(stderr, "%s:%d\tCPUID[0x%x]: eax=%d ebx=%d ecx=%d edx=%d\n", __FILE__, __LINE__, idx, a, b, c,d)
+#if defined(__i386__) && defined(__PIC__)
+#define CPUID(leaf, eax, ebx, ecx, edx)				\
+    __asm__ (							\
+	"xchgl %%ebx, %1;"					\
+	"cpuid;"						\
+	"xchgl %%ebx, %1"					\
+	: "=a" (eax), "=r" (ebx), "=c" (ecx), "=d" (edx)	\
+	: "0" (leaf));						\
+    if(debug_cpuid) fprintf(stderr, "%s:%d\tCPUID[0x%x]: eax=%d ebx=%d ecx=%d edx=%d\n", __FILE__, __LINE__, leaf, eax, ebx, ecx, edx)
+#else
+#define CPUID(leaf, eax, ebx, ecx, edx)				\
+    __asm__ (							\
+	"cpuid"							\
+	: "=a" (eax), "=b" (ebx), "=c" (ecx), "=d" (edx)	\
+	: "0" (leaf));						\
+    if(debug_cpuid) fprintf(stderr, "%s:%d\tCPUID[0x%x]: eax=%d ebx=%d ecx=%d edx=%d\n", __FILE__, __LINE__, leaf, eax, ebx, ecx, edx)
+#endif
