@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: cpuinfo.pm 494 2010-03-04 20:55:45Z liske $
+# $Id: cpuinfo.pm 539 2011-08-19 13:06:47Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -28,6 +28,7 @@ package ImVirt::Utils::cpuinfo;
 
 use strict;
 use warnings;
+use Data::Dumper;
 use ImVirt::Utils::procfs;
 
 require Exporter;
@@ -52,6 +53,7 @@ while(my $line = <HCPUINFO>) {
     }
 }
 close(HCPUINFO);
+ImVirt::debug(__PACKAGE__, Dumper(\%cpuinfo));
 
 sub cpuinfo_get() {
     return %cpuinfo;
