@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: kernel.pm 545 2012-01-15 20:36:06Z liske $
+# $Id: kernel.pm 577 2012-04-22 18:55:13Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -65,9 +65,10 @@ sub dmidecode_string($) {
 
     my $res = join(' ', @res);
 
-    ImVirt::debug(__PACKAGE__, "reading '$fn': $res");
-
-    return $res if($res);
+    if($res) {
+	ImVirt::debug(__PACKAGE__, "dmidecode_string($s) => $res");
+	return $res;
+    }
 
     return undef;
 }
@@ -82,7 +83,10 @@ sub dmidecode_type($) {
 
     my $res = join(' ', @res);
 
-    return $res if($res);
+    if($res) {
+	ImVirt::debug(__PACKAGE__, "dmidecode_type($_) => $res");
+	return $res;
+    }
 
     return undef;
 }
