@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: ksyms.pm 494 2010-03-04 20:55:45Z liske $
+# $Id: ksyms.pm 539 2011-08-19 13:06:47Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -28,6 +28,7 @@ package ImVirt::Utils::ksyms;
 
 use strict;
 use warnings;
+use Data::Dumper;
 use ImVirt::Utils::procfs;
 use constant {
     KSYM_STYPE_ABSOL	=> 'A',
@@ -79,6 +80,7 @@ while(<HKAS>) {
 	    ${$kallsyms{$3}}{'module'} = $5 if(defined($5));
 	}
 }
+ImVirt::debug(__PACKAGE__, Dumper(\%kallsyms));
 
 sub ksym_provides($$) {
     my ($type, $name) = @_;
