@@ -1,12 +1,12 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: sysfs.pm 494 2010-03-04 20:55:45Z liske $
+# $Id: sysfs.pm 562 2012-02-19 15:39:23Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
 #
 # Copyright Holder:
-#   2009 - 2010 (C) IBH IT-Service GmbH [http://www.ibh.de/]
+#   2009 - 2012 (C) IBH IT-Service GmbH [http://www.ibh.de/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,7 @@ our @EXPORT = qw(
     sysfs_read
 );
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 my $sysfsdir = '/sys';
 
@@ -52,7 +52,11 @@ sub sysfs_isdir($) {
 
 sub sysfs_read($) {
     my $fn = join('/', sysfs_getmp(), shift);
-    return read_file($fn) if(-r $fn);
+    if(-r $fn) {
+	my $f = read_file($fn);
+	chomp($f);
+	return $f;
+    }
 
     return undef;
 }
