@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: Generic.pm 521 2010-07-02 12:35:15Z liske $
+# $Id: Generic.pm 540 2011-08-19 13:10:18Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -43,8 +43,8 @@ sub detect($) {
 
     # Is hardware virtualization available?
     if(defined(my $f = cpuinfo_hasflags(
-	'vmx' => IMV_PTS_NORMAL,
-	'svm' => IMV_PTS_NORMAL,
+	'vmx' => IMV_PTS_MINOR,
+	'svm' => IMV_PTS_MINOR,
       ))) {
 	ImVirt::inc_pts($dref, $f, IMV_PHYSICAL) if($f > 0);
     }
