@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: OpenVZ.pm 517 2010-03-29 17:58:20Z liske $
+# $Id: OpenVZ.pm 521 2010-07-02 12:35:15Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -48,4 +48,7 @@ sub detect($) {
     }
 }
 
+sub pres() {
+    return (PRODUCT);
+}
 1;
